pub struct HistogramBucket {
pub index: u32,
pub count: u64,
}Expand description
One bucket of a histogram, used by the method LogIntegerHistogram.
Fields
index: u32count: u64Trait Implementations
Sourceimpl Clone for HistogramBucket
impl Clone for HistogramBucket
Sourcefn clone(&self) -> HistogramBucket
fn clone(&self) -> HistogramBucket
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HistogramBucket
impl Debug for HistogramBucket
Sourceimpl<'a, ___E> Encode<HistogramBucket, ___E> for &'a HistogramBucketwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<HistogramBucket, ___E> for &'a HistogramBucketwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HistogramBucket>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HistogramBucket>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<HistogramBucket, ___E> for HistogramBucketwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<HistogramBucket, ___E> for HistogramBucketwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HistogramBucket>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HistogramBucket>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, HistogramBucket>, ___E> for &'a HistogramBucket
impl<'a, ___E> EncodeOption<Box<'static, HistogramBucket>, ___E> for &'a HistogramBucket
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, HistogramBucket>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, HistogramBucket>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, HistogramBucket>, ___E> for HistogramBucket
impl<___E> EncodeOption<Box<'static, HistogramBucket>, ___E> for HistogramBucket
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, HistogramBucket>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, HistogramBucket>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<HistogramBucket> for HistogramBucket
impl FromWire<HistogramBucket> for HistogramBucket
Sourcefn from_wire(wire: HistogramBucket) -> Self
fn from_wire(wire: HistogramBucket) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<HistogramBucket> for HistogramBucket
impl FromWireRef<HistogramBucket> for HistogramBucket
Sourcefn from_wire_ref(wire: &HistogramBucket) -> Self
fn from_wire_ref(wire: &HistogramBucket) -> Self
Converts the given reference to this type.
Sourceimpl Hash for HistogramBucket
impl Hash for HistogramBucket
Sourceimpl Ord for HistogramBucket
impl Ord for HistogramBucket
Sourcefn cmp(&self, other: &HistogramBucket) -> Ordering
fn cmp(&self, other: &HistogramBucket) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HistogramBucket
impl PartialEq for HistogramBucket
Sourceimpl PartialOrd for HistogramBucket
impl PartialOrd for HistogramBucket
impl Copy for HistogramBucket
impl Eq for HistogramBucket
impl StructuralPartialEq for HistogramBucket