pub struct MetricEvent {
pub metric_id: u32,
pub event_codes: Vec<u32>,
pub payload: MetricEventPayload,
}Expand description
A specification of an event that occurred to be passed to LogMetricEvents().
Fields
metric_id: u32event_codes: Vec<u32>payload: MetricEventPayloadTrait Implementations
Sourceimpl Clone for MetricEvent
impl Clone for MetricEvent
Sourcefn clone(&self) -> MetricEvent
fn clone(&self) -> MetricEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetricEvent
impl Debug for MetricEvent
Sourceimpl<'a, ___E> Encode<MetricEvent<'static>, ___E> for &'a MetricEventwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<MetricEvent<'static>, ___E> for &'a MetricEventwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEvent<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEvent<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MetricEvent<'static>, ___E> for MetricEventwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<MetricEvent<'static>, ___E> for MetricEventwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEvent<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEvent<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MetricEvent<'static>>, ___E> for &'a MetricEvent
impl<'a, ___E> EncodeOption<Box<'static, MetricEvent<'static>>, ___E> for &'a MetricEvent
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEvent<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEvent<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MetricEvent<'static>>, ___E> for MetricEvent
impl<___E> EncodeOption<Box<'static, MetricEvent<'static>>, ___E> for MetricEvent
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEvent<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEvent<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MetricEvent<'de>> for MetricEvent
impl<'de> FromWire<MetricEvent<'de>> for MetricEvent
Sourcefn from_wire(wire: MetricEvent<'de>) -> Self
fn from_wire(wire: MetricEvent<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MetricEvent<'de>> for MetricEvent
impl<'de> FromWireRef<MetricEvent<'de>> for MetricEvent
Sourcefn from_wire_ref(wire: &MetricEvent<'de>) -> Self
fn from_wire_ref(wire: &MetricEvent<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for MetricEvent
impl Hash for MetricEvent
Sourceimpl Ord for MetricEvent
impl Ord for MetricEvent
Sourcefn cmp(&self, other: &MetricEvent) -> Ordering
fn cmp(&self, other: &MetricEvent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MetricEvent
impl PartialEq for MetricEvent
Sourceimpl PartialOrd for MetricEvent
impl PartialOrd for MetricEvent
impl Eq for MetricEvent
impl StructuralPartialEq for MetricEvent