pub struct MetricEventLoggerLogIntegerHistogramRequest {
pub metric_id: u32,
pub histogram: Vec<HistogramBucket>,
pub event_codes: Vec<u32>,
}Fields
metric_id: u32histogram: Vec<HistogramBucket>event_codes: Vec<u32>Trait Implementations
Sourceimpl Clone for MetricEventLoggerLogIntegerHistogramRequest
impl Clone for MetricEventLoggerLogIntegerHistogramRequest
Sourcefn clone(&self) -> MetricEventLoggerLogIntegerHistogramRequest
fn clone(&self) -> MetricEventLoggerLogIntegerHistogramRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<MetricEventLoggerLogIntegerHistogramRequest<'static>, ___E> for &'a MetricEventLoggerLogIntegerHistogramRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<MetricEventLoggerLogIntegerHistogramRequest<'static>, ___E> for &'a MetricEventLoggerLogIntegerHistogramRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEventLoggerLogIntegerHistogramRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEventLoggerLogIntegerHistogramRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MetricEventLoggerLogIntegerHistogramRequest<'static>, ___E> for MetricEventLoggerLogIntegerHistogramRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<MetricEventLoggerLogIntegerHistogramRequest<'static>, ___E> for MetricEventLoggerLogIntegerHistogramRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEventLoggerLogIntegerHistogramRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEventLoggerLogIntegerHistogramRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MetricEventLoggerLogIntegerHistogramRequest<'static>>, ___E> for &'a MetricEventLoggerLogIntegerHistogramRequestwhere
___E: Encoder + ?Sized,
&'a MetricEventLoggerLogIntegerHistogramRequest: Encode<MetricEventLoggerLogIntegerHistogramRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, MetricEventLoggerLogIntegerHistogramRequest<'static>>, ___E> for &'a MetricEventLoggerLogIntegerHistogramRequestwhere
___E: Encoder + ?Sized,
&'a MetricEventLoggerLogIntegerHistogramRequest: Encode<MetricEventLoggerLogIntegerHistogramRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogIntegerHistogramRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogIntegerHistogramRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MetricEventLoggerLogIntegerHistogramRequest<'static>>, ___E> for MetricEventLoggerLogIntegerHistogramRequestwhere
___E: Encoder + ?Sized,
MetricEventLoggerLogIntegerHistogramRequest: Encode<MetricEventLoggerLogIntegerHistogramRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MetricEventLoggerLogIntegerHistogramRequest<'static>>, ___E> for MetricEventLoggerLogIntegerHistogramRequestwhere
___E: Encoder + ?Sized,
MetricEventLoggerLogIntegerHistogramRequest: Encode<MetricEventLoggerLogIntegerHistogramRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogIntegerHistogramRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogIntegerHistogramRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MetricEventLoggerLogIntegerHistogramRequest<'de>> for MetricEventLoggerLogIntegerHistogramRequest
impl<'de> FromWire<MetricEventLoggerLogIntegerHistogramRequest<'de>> for MetricEventLoggerLogIntegerHistogramRequest
Sourcefn from_wire(wire: MetricEventLoggerLogIntegerHistogramRequest<'de>) -> Self
fn from_wire(wire: MetricEventLoggerLogIntegerHistogramRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MetricEventLoggerLogIntegerHistogramRequest<'de>> for MetricEventLoggerLogIntegerHistogramRequest
impl<'de> FromWireRef<MetricEventLoggerLogIntegerHistogramRequest<'de>> for MetricEventLoggerLogIntegerHistogramRequest
Sourcefn from_wire_ref(
wire: &MetricEventLoggerLogIntegerHistogramRequest<'de>,
) -> Self
fn from_wire_ref( wire: &MetricEventLoggerLogIntegerHistogramRequest<'de>, ) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MetricEventLoggerLogIntegerHistogramRequest
impl Ord for MetricEventLoggerLogIntegerHistogramRequest
Sourcefn cmp(&self, other: &MetricEventLoggerLogIntegerHistogramRequest) -> Ordering
fn cmp(&self, other: &MetricEventLoggerLogIntegerHistogramRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MetricEventLoggerLogIntegerHistogramRequest
impl PartialEq for MetricEventLoggerLogIntegerHistogramRequest
Sourcefn eq(&self, other: &MetricEventLoggerLogIntegerHistogramRequest) -> bool
fn eq(&self, other: &MetricEventLoggerLogIntegerHistogramRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MetricEventLoggerLogIntegerHistogramRequest
impl PartialOrd for MetricEventLoggerLogIntegerHistogramRequest
impl Eq for MetricEventLoggerLogIntegerHistogramRequest
impl StructuralPartialEq for MetricEventLoggerLogIntegerHistogramRequest