pub struct MetricEventLoggerLogMetricEventsRequest {
pub events: Vec<MetricEvent>,
}Fields
events: Vec<MetricEvent>Trait Implementations
Sourceimpl Clone for MetricEventLoggerLogMetricEventsRequest
impl Clone for MetricEventLoggerLogMetricEventsRequest
Sourcefn clone(&self) -> MetricEventLoggerLogMetricEventsRequest
fn clone(&self) -> MetricEventLoggerLogMetricEventsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<MetricEventLoggerLogMetricEventsRequest<'static>, ___E> for &'a MetricEventLoggerLogMetricEventsRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<MetricEventLoggerLogMetricEventsRequest<'static>, ___E> for &'a MetricEventLoggerLogMetricEventsRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEventLoggerLogMetricEventsRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEventLoggerLogMetricEventsRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MetricEventLoggerLogMetricEventsRequest<'static>, ___E> for MetricEventLoggerLogMetricEventsRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<MetricEventLoggerLogMetricEventsRequest<'static>, ___E> for MetricEventLoggerLogMetricEventsRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEventLoggerLogMetricEventsRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEventLoggerLogMetricEventsRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MetricEventLoggerLogMetricEventsRequest<'static>>, ___E> for &'a MetricEventLoggerLogMetricEventsRequestwhere
___E: Encoder + ?Sized,
&'a MetricEventLoggerLogMetricEventsRequest: Encode<MetricEventLoggerLogMetricEventsRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, MetricEventLoggerLogMetricEventsRequest<'static>>, ___E> for &'a MetricEventLoggerLogMetricEventsRequestwhere
___E: Encoder + ?Sized,
&'a MetricEventLoggerLogMetricEventsRequest: Encode<MetricEventLoggerLogMetricEventsRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogMetricEventsRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogMetricEventsRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MetricEventLoggerLogMetricEventsRequest<'static>>, ___E> for MetricEventLoggerLogMetricEventsRequestwhere
___E: Encoder + ?Sized,
MetricEventLoggerLogMetricEventsRequest: Encode<MetricEventLoggerLogMetricEventsRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MetricEventLoggerLogMetricEventsRequest<'static>>, ___E> for MetricEventLoggerLogMetricEventsRequestwhere
___E: Encoder + ?Sized,
MetricEventLoggerLogMetricEventsRequest: Encode<MetricEventLoggerLogMetricEventsRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogMetricEventsRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogMetricEventsRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MetricEventLoggerLogMetricEventsRequest<'de>> for MetricEventLoggerLogMetricEventsRequest
impl<'de> FromWire<MetricEventLoggerLogMetricEventsRequest<'de>> for MetricEventLoggerLogMetricEventsRequest
Sourcefn from_wire(wire: MetricEventLoggerLogMetricEventsRequest<'de>) -> Self
fn from_wire(wire: MetricEventLoggerLogMetricEventsRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MetricEventLoggerLogMetricEventsRequest<'de>> for MetricEventLoggerLogMetricEventsRequest
impl<'de> FromWireRef<MetricEventLoggerLogMetricEventsRequest<'de>> for MetricEventLoggerLogMetricEventsRequest
Sourcefn from_wire_ref(wire: &MetricEventLoggerLogMetricEventsRequest<'de>) -> Self
fn from_wire_ref(wire: &MetricEventLoggerLogMetricEventsRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MetricEventLoggerLogMetricEventsRequest
impl Ord for MetricEventLoggerLogMetricEventsRequest
Sourcefn cmp(&self, other: &MetricEventLoggerLogMetricEventsRequest) -> Ordering
fn cmp(&self, other: &MetricEventLoggerLogMetricEventsRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MetricEventLoggerLogMetricEventsRequest
impl PartialEq for MetricEventLoggerLogMetricEventsRequest
Sourcefn eq(&self, other: &MetricEventLoggerLogMetricEventsRequest) -> bool
fn eq(&self, other: &MetricEventLoggerLogMetricEventsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MetricEventLoggerLogMetricEventsRequest
impl PartialOrd for MetricEventLoggerLogMetricEventsRequest
impl Eq for MetricEventLoggerLogMetricEventsRequest
impl StructuralPartialEq for MetricEventLoggerLogMetricEventsRequest