pub struct MetricEventLoggerLogOccurrenceRequest {
pub metric_id: u32,
pub count: u64,
pub event_codes: Vec<u32>,
}Fields
metric_id: u32count: u64event_codes: Vec<u32>Trait Implementations
Sourceimpl Clone for MetricEventLoggerLogOccurrenceRequest
impl Clone for MetricEventLoggerLogOccurrenceRequest
Sourcefn clone(&self) -> MetricEventLoggerLogOccurrenceRequest
fn clone(&self) -> MetricEventLoggerLogOccurrenceRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<MetricEventLoggerLogOccurrenceRequest<'static>, ___E> for &'a MetricEventLoggerLogOccurrenceRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<MetricEventLoggerLogOccurrenceRequest<'static>, ___E> for &'a MetricEventLoggerLogOccurrenceRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEventLoggerLogOccurrenceRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEventLoggerLogOccurrenceRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MetricEventLoggerLogOccurrenceRequest<'static>, ___E> for MetricEventLoggerLogOccurrenceRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<MetricEventLoggerLogOccurrenceRequest<'static>, ___E> for MetricEventLoggerLogOccurrenceRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetricEventLoggerLogOccurrenceRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetricEventLoggerLogOccurrenceRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MetricEventLoggerLogOccurrenceRequest<'static>>, ___E> for &'a MetricEventLoggerLogOccurrenceRequestwhere
___E: Encoder + ?Sized,
&'a MetricEventLoggerLogOccurrenceRequest: Encode<MetricEventLoggerLogOccurrenceRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, MetricEventLoggerLogOccurrenceRequest<'static>>, ___E> for &'a MetricEventLoggerLogOccurrenceRequestwhere
___E: Encoder + ?Sized,
&'a MetricEventLoggerLogOccurrenceRequest: Encode<MetricEventLoggerLogOccurrenceRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogOccurrenceRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogOccurrenceRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MetricEventLoggerLogOccurrenceRequest<'static>>, ___E> for MetricEventLoggerLogOccurrenceRequestwhere
___E: Encoder + ?Sized,
MetricEventLoggerLogOccurrenceRequest: Encode<MetricEventLoggerLogOccurrenceRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MetricEventLoggerLogOccurrenceRequest<'static>>, ___E> for MetricEventLoggerLogOccurrenceRequestwhere
___E: Encoder + ?Sized,
MetricEventLoggerLogOccurrenceRequest: Encode<MetricEventLoggerLogOccurrenceRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogOccurrenceRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetricEventLoggerLogOccurrenceRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MetricEventLoggerLogOccurrenceRequest<'de>> for MetricEventLoggerLogOccurrenceRequest
impl<'de> FromWire<MetricEventLoggerLogOccurrenceRequest<'de>> for MetricEventLoggerLogOccurrenceRequest
Sourcefn from_wire(wire: MetricEventLoggerLogOccurrenceRequest<'de>) -> Self
fn from_wire(wire: MetricEventLoggerLogOccurrenceRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MetricEventLoggerLogOccurrenceRequest<'de>> for MetricEventLoggerLogOccurrenceRequest
impl<'de> FromWireRef<MetricEventLoggerLogOccurrenceRequest<'de>> for MetricEventLoggerLogOccurrenceRequest
Sourcefn from_wire_ref(wire: &MetricEventLoggerLogOccurrenceRequest<'de>) -> Self
fn from_wire_ref(wire: &MetricEventLoggerLogOccurrenceRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MetricEventLoggerLogOccurrenceRequest
impl Ord for MetricEventLoggerLogOccurrenceRequest
Sourcefn cmp(&self, other: &MetricEventLoggerLogOccurrenceRequest) -> Ordering
fn cmp(&self, other: &MetricEventLoggerLogOccurrenceRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MetricEventLoggerLogOccurrenceRequest
impl PartialEq for MetricEventLoggerLogOccurrenceRequest
Sourcefn eq(&self, other: &MetricEventLoggerLogOccurrenceRequest) -> bool
fn eq(&self, other: &MetricEventLoggerLogOccurrenceRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MetricEventLoggerLogOccurrenceRequest
impl PartialOrd for MetricEventLoggerLogOccurrenceRequest
impl Eq for MetricEventLoggerLogOccurrenceRequest
impl StructuralPartialEq for MetricEventLoggerLogOccurrenceRequest